//-----------------------------------------------------------------------------
// File: BasicHLSL.fx
//
// Desc: The effect file for the BasicHLSL sample.  It implemetns 
// 
// Copyright (c) Microsoft Corporation. All rights reserved.
//-----------------------------------------------------------------------------


//-----------------------------------------------------------------------------
// Global variables
//-----------------------------------------------------------------------------
float4 g_MaterialAmbientColor;	// Material's ambient color
float4 g_MaterialDiffuseColor;	// Material's diffuse color

// This effect file uses a single directional light
float3 g_LightDir = normalize(float3(1.0f, 1.0f, 1.0f));	// Light's direction in world space
float4 g_LightAmbient = { 1.0f, 1.0f, 1.0f, 1.0f };			// Light's ambient color
float4 g_LightDiffuse = { 1.0f, 1.0f, 1.0f, 1.0f };			// Light's diffuse color

texture Texture0;			// Color texture for mesh

float	 Time;					// App's time in seconds
float4x4 WorldMat;					// World matrix for object
float4x4 WorldViewProjection;	// World * View * Projection matrix
float4x4 ViewMat;
static const int MAX_MATRICES = 20;
float4x3    BoneMat[MAX_MATRICES] : WORLDMATRIXARRAY;

//-----------------------------------------------------------------------------
// Texture samplers
//-----------------------------------------------------------------------------
sampler MeshTextureSampler = 
sampler_state
{
    Texture = <Texture0>;    
    MipFilter = LINEAR;
    MinFilter = LINEAR;
    MagFilter = LINEAR;
};


//-----------------------------------------------------------------------------
// Vertex shader output structure
//-----------------------------------------------------------------------------
struct VS_OUTPUT
{
    float4 Position   : POSITION;   // vertex position 
//	float4 Color: COLOR0;
	float2 TextureUV : TEXCOORD0;
};


//-----------------------------------------------------------------------------
// Name: RenderSceneVS
// Type: Vertex shader                                      
// Desc: This shader computes standard transform and lighting
//-----------------------------------------------------------------------------
VS_OUTPUT RenderSceneVS( float4 vPos : POSITION, 
                         float2 vTexCoord0 : TEXCOORD0//,
						// float4 col: COLOR0
						 )
{
    VS_OUTPUT Output;
    // Transform the position from obj	ect space to homogeneous projection space
	// Animation the vertex based on time and the vertex's object space position
   // float4 vAnimatedPos = vPos;//mul(vPos,WorldMat);// + float4( sin(Time) * vPos.x/2, 0, 0, 0 );
    
    // Transform the position from object space to homogeneous projection space
    Output.Position = mul(vPos, WorldViewProjection);
    Output.TextureUV = vTexCoord0;
	//Output.Color = col;
    return Output;    
}


//-----------------------------------------------------------------------------
// Pixel shader output structure
//-----------------------------------------------------------------------------
struct PS_OUTPUT
{
    float4 RGBColor : COLOR0;  // Pixel color    
};


//-----------------------------------------------------------------------------
// Name: RenderScenePS                                        
// Type: Pixel shader
// Desc: This shader outputs the pixel's color by modulating the texture's
//		 color with diffuse material color
//-----------------------------------------------------------------------------
PS_OUTPUT RenderScenePS( VS_OUTPUT In ) 
{ 
    PS_OUTPUT Output;

    // Lookup mesh texture and modulate it with diffuse
    //Output.RGBColor = float4(1,.2,.1,1);
	Output.RGBColor =tex2D(MeshTextureSampler, In.TextureUV);//*In.Color;
    return Output;
}



//-----------------------------------------------------------------------------
// Name: RenderScene
// Type: Technique                                     
// Desc: Renders scene to render target
//-----------------------------------------------------------------------------
technique DefaultRender
{
    pass P0
    {          
        VertexShader = compile vs_1_1 RenderSceneVS();
        PixelShader  = compile ps_1_1 RenderScenePS(); // trival pixel shader (could use FF instead if desired)
    }
}
